#
# spec file for package perl-Module-Build-Tiny
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Module-Build-Tiny
Name:           perl-Module-Build-Tiny
Version:        0.51.0
Release:        1.1
# 0.051 -> normalize -> 0.51.0
%define cpan_version 0.051
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Tiny replacement for Module::Build
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/L/LE/LEONT/%{cpan_name}-%{cpan_version}.tar.gz
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(CPAN::Meta)
BuildRequires:  perl(ExtUtils::CBuilder)
BuildRequires:  perl(ExtUtils::Config) >= 0.003
BuildRequires:  perl(ExtUtils::Helpers) >= 0.020
BuildRequires:  perl(ExtUtils::InstallPaths) >= 0.002
BuildRequires:  perl(ExtUtils::ParseXS)
BuildRequires:  perl(Getopt::Long) >= 2.36
BuildRequires:  perl(JSON::PP) >= 2
BuildRequires:  perl(Module::Build)
BuildRequires:  perl(TAP::Harness::Env)
BuildRequires:  perl(Test::More) >= 0.88
Requires:       perl(CPAN::Meta)
Requires:       perl(ExtUtils::CBuilder)
Requires:       perl(ExtUtils::Config) >= 0.003
Requires:       perl(ExtUtils::Helpers) >= 0.020
Requires:       perl(ExtUtils::InstallPaths) >= 0.002
Requires:       perl(ExtUtils::ParseXS)
Requires:       perl(Getopt::Long) >= 2.36
Requires:       perl(JSON::PP) >= 2
Requires:       perl(TAP::Harness::Env)
Provides:       perl(Module::Build::Tiny) = %{version}
%undefine       __perllib_provides
Recommends:     perl(CPAN::Requirements::Dynamic)
%{perl_requires}

%description
Many Perl distributions use a Build.PL file instead of a Makefile.PL file
to drive distribution configuration, build, test and installation.
Traditionally, Build.PL uses Module::Build as the underlying build system.
This module provides a simple, lightweight, drop-in replacement.

Whereas Module::Build has over 6,700 lines of code; this module has less
than 200, yet supports the features needed by most distributions.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README Todo
%license LICENSE

%changelog
* Sat Sep  7 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.51.0 (0.051)
  see /usr/share/doc/packages/perl-Module-Build-Tiny/Changes
  0.051     2024-09-06 11:05:08+02:00 Europe/Brussels
  - Make CPAN::Requirements::Dynamic an optional dependency
  0.050     2024-09-04 10:21:13+02:00 Europe/Brussels
  - Revert "Make CPAN::Requirements::Dynamic an optional dependency"
  0.049     2024-09-03 19:25:05+02:00 Europe/Brussels
  - Make CPAN::Requirements::Dynamic an optional dependency
* Sun Jun 23 2024 Tina Müller <tina.mueller@suse.com>
- updated to 0.48.0 (0.048)
  see /usr/share/doc/packages/perl-Module-Build-Tiny/Changes
  0.048     2024-04-28 14:58:04+02:00 Europe/Brussels
  - Implement dynamic prerequisites
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Fri Sep 29 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.047
  see /usr/share/doc/packages/perl-Module-Build-Tiny/Changes
  0.047     2023-09-28 17:53:41+02:00 Europe/Brussels
  - Avoid using empty regex for backwards compatability
* Tue Jun 13 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.046
  see /usr/share/doc/packages/perl-Module-Build-Tiny/Changes
  0.046     2023-06-01 19:31:21+02:00 Europe/Amsterdam
  - Add src/ to include paths
  0.045     2023-04-30 11:52:20+02:00 Europe/Brussels
  - Fix compilation issue on Windows
  0.044     2023-04-28 09:19:30+02:00 Europe/Brussels
  - Add module sharedirs
  - Only add src/*.c files to primary XS file
  0.043     2023-04-19 02:05:14+02:00 Europe/Amsterdam
  - Fix manification test for perls without man paths
  0.042     2023-04-18 23:32:40+02:00 Europe/Amsterdam
  - Restore manpage generation
  - Add include/ to include paths
  - Compile all .c files in src/
  0.041     2023-04-17 16:03:06+02:00 Europe/Amsterdam
  - Released without changes from 0.040
  0.040     2023-02-05 23:06:28+01:00 Europe/Amsterdam (TRIAL RELEASE)
  - Manify .pod after .pm
  - Filter out script documentation from scripts
  - Don't manify podless modules/scripts
* Mon Oct 27 2014 ncutler@suse.com
- updated to 0.039
  * Supply basename to *.PL files as its args
* Mon Sep 15 2014 coolo@suse.com
- updated to 0.038
    Scrub PERL_MB_OPT in tests too
    Scrub environment variable in tests
* Sat Jul 19 2014 chris@computersalat.de
- update to 0.36
  * Add --jobs argument to MBT
  * Add xs directory to include list
* Mon Mar 10 2014 coolo@suse.com
- updated to 0.035
  Fix install test in absence of a compiler
* Sun Feb  9 2014 coolo@suse.com
- updated to 0.034
    Make install tests more platform independent
    Require Getopt::Long 2.36
    Add install tests
    Fix env options and Build.PL options being ignored (regression in 0.031)
    Process argument sources separately
    Use mod2fname appropriately
* Mon Nov 25 2013 coolo@suse.com
- updated to 0.030
    Added workaround for #54606
    Respect harness environmental variables
    Add main dir to include path
* Fri Oct  4 2013 coolo@suse.com
- updated to 0.028
    Revert "Removed clean and realclean actions"
    Build .c and .o in temp/ instead of lib
    Got rid of IO layers
    Separate libdoc and bindoc checks
    Various documentation updates
    Safe PERL_MB_OPT during configuration stage
* Sat Jul 27 2013 coolo@suse.com
- updated to 0.025
    Use local tempdir
    Generate man pages in the correct section
* Wed Jun  5 2013 coolo@suse.com
- initial package 0.023
  * created by cpanspec 1.78.06
